# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Information utility module for NIFCLOUD.

Define class for information about backup, data copy and so on.
"""


from iobase.xmldata import (XmlNode)
from ionas.backupsync.info import (ConnectionInfo, TargetInfo,)


NAME_NAME = "name"
ID_NAME = "id"
ACCOUNTNAME_NAME = "accountname"
ACCESSKEY_NAME = "accesskey"
HTTPMETHOD_NAME = "httpmethod"

TYPE_NAME = "type"
CONTAINER_NAME = "container"
SUBDIR_NAME = "subdir"


class AzureConnectionInfo(ConnectionInfo):
    """Class for Azure connection information."""

    def __init__(self, connection_xml):
        """Constructor."""

        super(AzureConnectionInfo, self).__init__(
                                    connection_xml.get_value(NAME_NAME))

        self.id = connection_xml.get_value(ID_NAME, "")
        self.accountname = connection_xml.get_value(ACCOUNTNAME_NAME, "")
        self.accesskey = connection_xml.get_value(ACCESSKEY_NAME, "")
        self.httpmethod = connection_xml.get_value(HTTPMETHOD_NAME, "")


class AzureTargetInfo(TargetInfo):
    """Class for Azure target information."""

    def __init__(self, target_xml, connection_xml):
        """Constructor."""

        super(AzureTargetInfo, self).__init__(
                                target_xml.get_value(TYPE_NAME),
                                AzureConnectionInfo(connection_xml))

        self.container = target_xml.get_value(CONTAINER_NAME, "")
        self.subdir = target_xml.get_value(SUBDIR_NAME, "")

    def get_root_path(self):
        return u"/"

    def get_target_name(self):
        target_name = "azure_" + self.connection_info.name
        if isinstance(target_name, str):
            target_name = target_name.decode("UTF8")

        return target_name

    def do_wait_modified(self):
        return False
