# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Information utility module for flets azukeru.

Define class for information about backup, data copy and so on.
"""


from iobase.xmldata import (XmlNode)
from ionas.backupsync.info import (TargetInfo,)



NAME_NAME = "name"
ID_NAME = "id"
CONTRACTOR_NAME = "contractor"
PLAN_NAME = "plan"
AUTHMETHOD_NAME = "authmethod"
OTHERAUTHMETHOD_NAME = "otherauthmethod"
TERMINALKEY_NAME = "terminalkey"
CLIENTID_NAME = "clientid"
PASSWORD_NAME = "password"
TYPE_NAME = "type"
SHARENAME_NAME = "sharename"
SUBDIR_NAME = "subdir"


class LocalTargetInfo(TargetInfo):
    """Class for flets azukeru target information."""

    def __init__(self, target_xml):
        """Constructor."""

        super(LocalTargetInfo, self).__init__(
                                target_xml.get_value(TYPE_NAME), None)

        self.sharename = target_xml.get_value(SHARENAME_NAME)
        self.subdir = target_xml.get_value(SUBDIR_NAME, "")

    def get_root_path(self):
        if self.sharename in ["usb1", "usb2", "usb3", "usb4"]:
            return u"/mnt/" + self.sharename

        root_path = u"/mnt/sataraid1/share/"
        share_name = self.sharename
        if isinstance(share_name, str):
            share_name = share_name.decode("UTF8")

        return root_path + share_name

    def get_target_name(self):
        target_name = self.sharename
        if isinstance(target_name, str):
            target_name = target_name.decode("UTF8")

        return target_name

    def do_wait_modified(self):
        return True
