# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from __future__ import print_function
from __future__ import unicode_literals
from __future__ import absolute_import
from __future__ import division

import os

from django.utils.translation import ugettext as _
from django import forms
from django.forms.formsets import formset_factory

from project.view import FuncView as _View
from project.forms.fields.extras.validators.fal import FALValidator


ACCOUNTNAME_MAX_LENGTH = 255
ACCESSKEY_MAX_LENGTH = 255
CONTAINER_MAX_LENGTH = 63
CONTAINER_MIN_LENGTH = 3


class NameField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', '接続名')
        super(NameField, self).__init__(*args, **kwargs)


class AccountnameValidator(FALValidator):
    validator = 'NoCheck'
    options = {
        'max_length': ACCOUNTNAME_MAX_LENGTH,
    }
class AccountnameField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'アカウント名')
        kwargs['validators'] = kwargs.get('validators', [AccountnameValidator()])
        super(AccountnameField, self).__init__(*args, **kwargs)


class AccesskeyValidator(FALValidator):
    validator = 'NoCheck'
    options = {
        'max_length': ACCESSKEY_MAX_LENGTH,
    }
class AccesskeyField(forms.CharField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'アクセスキー')
        kwargs['validators'] = kwargs.get('validators', [AccesskeyValidator()])
        super(AccesskeyField, self).__init__(*args, **kwargs)


class HttpmethodField(forms.ChoiceField):
    def __init__(self, *args, **kwargs):
        kwargs['label'] = kwargs.get('label', 'プロトコル')
        kwargs['widget'] = kwargs.get('widget', forms.widgets.RadioSelect)
        kwargs['choices'] = kwargs.get('choices', [
            ('http', 'http'),
            ('https', 'https'),
        ])
        kwargs['initial'] = kwargs.get('initial', kwargs['choices'][1][0])
        super(HttpmethodField, self).__init__(*args, **kwargs)
